##
## Loads a MEM trigram model, and uses it to compute
## the probabilitity of the input sequence
##
##  Usage:   python3 prob.py model.dat <text
##

import sys

from MEmodel import MEM, ngrams, extract_features

## MAIN ---------------------

## -- load ME trigram model
model = MEM(sys.argv[1])

## compute input probability
prob=1.0
n=0
print("trig  P(z|xy)\tP.accum      Perp")
for xyz in ngrams(sys.stdin, 3) :
  xy = xyz[0:2]
  z = xyz[2]
  feats = extract_features(xy)
  pt = model.conditional_prob(feats,z)
  prob *= pt
  n += 1
  perp = pow(prob, -1/n) if prob>0 else float('inf')
  print(f"{xyz}   {pt:.5f}\t{prob:<9.4g}   {perp:5.1f}")

print(f"TOTAL     \t{prob:<9.4g}   {perp:5.1f}")

